var namespace_data_provider =
[
    [ "AbstractDataField", "class_data_provider_1_1_abstract_data_field.html", "class_data_provider_1_1_abstract_data_field" ],
    [ "AbstractDataProcessor", "class_data_provider_1_1_abstract_data_processor.html", "class_data_provider_1_1_abstract_data_processor" ],
    [ "AbstractDataProvider", "class_data_provider_1_1_abstract_data_provider.html", "class_data_provider_1_1_abstract_data_provider" ],
    [ "AbstractDataProviderBulkOperation", "class_data_provider_1_1_abstract_data_provider_bulk_operation.html", "class_data_provider_1_1_abstract_data_provider_bulk_operation" ],
    [ "AbstractDataProviderBulkRecordInterface", "class_data_provider_1_1_abstract_data_provider_bulk_record_interface.html", "class_data_provider_1_1_abstract_data_provider_bulk_record_interface" ],
    [ "AbstractDataProviderFactory", "class_data_provider_1_1_abstract_data_provider_factory.html", "class_data_provider_1_1_abstract_data_provider_factory" ],
    [ "AbstractDataProviderRecordIterator", "class_data_provider_1_1_abstract_data_provider_record_iterator.html", "class_data_provider_1_1_abstract_data_provider_record_iterator" ],
    [ "AbstractDataProviderType", "class_data_provider_1_1_abstract_data_provider_type.html", "class_data_provider_1_1_abstract_data_provider_type" ],
    [ "DataFieldInfo", "struct_data_provider_1_1_data_field_info.html", "struct_data_provider_1_1_data_field_info" ],
    [ "DataProvider", "class_data_provider_1_1_data_provider.html", "class_data_provider_1_1_data_provider" ],
    [ "DataProviderBulkRecordIterator", "class_data_provider_1_1_data_provider_bulk_record_iterator.html", "class_data_provider_1_1_data_provider_bulk_record_iterator" ],
    [ "DataProviderExpression", "struct_data_provider_1_1_data_provider_expression.html", "struct_data_provider_1_1_data_provider_expression" ],
    [ "DataProviderExpressionInfo", "struct_data_provider_1_1_data_provider_expression_info.html", "struct_data_provider_1_1_data_provider_expression_info" ],
    [ "DataProviderFactoryInfo", "struct_data_provider_1_1_data_provider_factory_info.html", "struct_data_provider_1_1_data_provider_factory_info" ],
    [ "DataProviderFieldReference", "struct_data_provider_1_1_data_provider_field_reference.html", "struct_data_provider_1_1_data_provider_field_reference" ],
    [ "DataProviderInfo", "struct_data_provider_1_1_data_provider_info.html", "struct_data_provider_1_1_data_provider_info" ],
    [ "DataProviderOptionInfo", "struct_data_provider_1_1_data_provider_option_info.html", "struct_data_provider_1_1_data_provider_option_info" ],
    [ "DataProviderPipeline", "class_data_provider_1_1_data_provider_pipeline.html", "class_data_provider_1_1_data_provider_pipeline" ],
    [ "DataProviderPipelineFactory", "class_data_provider_1_1_data_provider_pipeline_factory.html", "class_data_provider_1_1_data_provider_pipeline_factory" ],
    [ "DataProviderSignatureTypeInfo", "struct_data_provider_1_1_data_provider_signature_type_info.html", "struct_data_provider_1_1_data_provider_signature_type_info" ],
    [ "DataProviderSummaryInfo", "struct_data_provider_1_1_data_provider_summary_info.html", "struct_data_provider_1_1_data_provider_summary_info" ],
    [ "DataProviderTypeCache", "class_data_provider_1_1_data_provider_type_cache.html", "class_data_provider_1_1_data_provider_type_cache" ],
    [ "DataProviderTypeEntry", "class_data_provider_1_1_data_provider_type_entry.html", "class_data_provider_1_1_data_provider_type_entry" ],
    [ "DataProviderTypeEntryInfo", "struct_data_provider_1_1_data_provider_type_entry_info.html", "struct_data_provider_1_1_data_provider_type_entry_info" ],
    [ "DataProviderTypeOptionInfo", "struct_data_provider_1_1_data_provider_type_option_info.html", "struct_data_provider_1_1_data_provider_type_option_info" ],
    [ "DataTypeInfo", "struct_data_provider_1_1_data_type_info.html", "struct_data_provider_1_1_data_type_info" ],
    [ "DefaultBulkInserter", "class_data_provider_1_1_default_bulk_inserter.html", "class_data_provider_1_1_default_bulk_inserter" ],
    [ "DefaultBulkRecordIterface", "class_data_provider_1_1_default_bulk_record_iterface.html", "class_data_provider_1_1_default_bulk_record_iterface" ],
    [ "DefaultBulkUpserter", "class_data_provider_1_1_default_bulk_upserter.html", "class_data_provider_1_1_default_bulk_upserter" ],
    [ "DefaultRecordIterator", "class_data_provider_1_1_default_record_iterator.html", "class_data_provider_1_1_default_record_iterator" ],
    [ "HashDataType", "class_data_provider_1_1_hash_data_type.html", "class_data_provider_1_1_hash_data_type" ],
    [ "HashDeclDataType", "class_data_provider_1_1_hash_decl_data_type.html", "class_data_provider_1_1_hash_decl_data_type" ],
    [ "ListDataType", "class_data_provider_1_1_list_data_type.html", "class_data_provider_1_1_list_data_type" ],
    [ "NullDataProvider", "class_data_provider_1_1_null_data_provider.html", "class_data_provider_1_1_null_data_provider" ],
    [ "NullDataProviderFactory", "class_data_provider_1_1_null_data_provider_factory.html", "class_data_provider_1_1_null_data_provider_factory" ],
    [ "PipelineFactoryInfo", "struct_data_provider_1_1_pipeline_factory_info.html", "struct_data_provider_1_1_pipeline_factory_info" ],
    [ "PipelineInfo", "struct_data_provider_1_1_pipeline_info.html", "struct_data_provider_1_1_pipeline_info" ],
    [ "PipelineOptionInfo", "struct_data_provider_1_1_pipeline_option_info.html", "struct_data_provider_1_1_pipeline_option_info" ],
    [ "PipelineQueue", "class_data_provider_1_1_pipeline_queue.html", "class_data_provider_1_1_pipeline_queue" ],
    [ "QoreBinaryDataType", "class_data_provider_1_1_qore_binary_data_type.html", "class_data_provider_1_1_qore_binary_data_type" ],
    [ "QoreBinaryDataTypeBase", "class_data_provider_1_1_qore_binary_data_type_base.html", "class_data_provider_1_1_qore_binary_data_type_base" ],
    [ "QoreBinaryOrNothingDataType", "class_data_provider_1_1_qore_binary_or_nothing_data_type.html", "class_data_provider_1_1_qore_binary_or_nothing_data_type" ],
    [ "QoreBoolDataType", "class_data_provider_1_1_qore_bool_data_type.html", "class_data_provider_1_1_qore_bool_data_type" ],
    [ "QoreBoolDataTypeBase", "class_data_provider_1_1_qore_bool_data_type_base.html", "class_data_provider_1_1_qore_bool_data_type_base" ],
    [ "QoreBoolOrNothingDataType", "class_data_provider_1_1_qore_bool_or_nothing_data_type.html", "class_data_provider_1_1_qore_bool_or_nothing_data_type" ],
    [ "QoreDataField", "class_data_provider_1_1_qore_data_field.html", "class_data_provider_1_1_qore_data_field" ],
    [ "QoreDataType", "class_data_provider_1_1_qore_data_type.html", "class_data_provider_1_1_qore_data_type" ],
    [ "QoreDateDataType", "class_data_provider_1_1_qore_date_data_type.html", "class_data_provider_1_1_qore_date_data_type" ],
    [ "QoreDateDataTypeBase", "class_data_provider_1_1_qore_date_data_type_base.html", "class_data_provider_1_1_qore_date_data_type_base" ],
    [ "QoreDateOrNothingDataType", "class_data_provider_1_1_qore_date_or_nothing_data_type.html", "class_data_provider_1_1_qore_date_or_nothing_data_type" ],
    [ "QoreFloatDataType", "class_data_provider_1_1_qore_float_data_type.html", "class_data_provider_1_1_qore_float_data_type" ],
    [ "QoreFloatDataTypeBase", "class_data_provider_1_1_qore_float_data_type_base.html", "class_data_provider_1_1_qore_float_data_type_base" ],
    [ "QoreFloatOrNothingDataType", "class_data_provider_1_1_qore_float_or_nothing_data_type.html", "class_data_provider_1_1_qore_float_or_nothing_data_type" ],
    [ "QoreHashDataType", "class_data_provider_1_1_qore_hash_data_type.html", "class_data_provider_1_1_qore_hash_data_type" ],
    [ "QoreIntDataType", "class_data_provider_1_1_qore_int_data_type.html", "class_data_provider_1_1_qore_int_data_type" ],
    [ "QoreIntDataTypeBase", "class_data_provider_1_1_qore_int_data_type_base.html", "class_data_provider_1_1_qore_int_data_type_base" ],
    [ "QoreIntOrNothingDataType", "class_data_provider_1_1_qore_int_or_nothing_data_type.html", "class_data_provider_1_1_qore_int_or_nothing_data_type" ],
    [ "QoreListDataType", "class_data_provider_1_1_qore_list_data_type.html", "class_data_provider_1_1_qore_list_data_type" ],
    [ "QoreNumberDataType", "class_data_provider_1_1_qore_number_data_type.html", "class_data_provider_1_1_qore_number_data_type" ],
    [ "QoreNumberDataTypeBase", "class_data_provider_1_1_qore_number_data_type_base.html", "class_data_provider_1_1_qore_number_data_type_base" ],
    [ "QoreNumberOrNothingDataType", "class_data_provider_1_1_qore_number_or_nothing_data_type.html", "class_data_provider_1_1_qore_number_or_nothing_data_type" ],
    [ "QoreSoftBinaryDataType", "class_data_provider_1_1_qore_soft_binary_data_type.html", "class_data_provider_1_1_qore_soft_binary_data_type" ],
    [ "QoreSoftBinaryNoNullDataType", "class_data_provider_1_1_qore_soft_binary_no_null_data_type.html", "class_data_provider_1_1_qore_soft_binary_no_null_data_type" ],
    [ "QoreSoftBinaryOrNothingDataType", "class_data_provider_1_1_qore_soft_binary_or_nothing_data_type.html", "class_data_provider_1_1_qore_soft_binary_or_nothing_data_type" ],
    [ "QoreSoftBoolDataType", "class_data_provider_1_1_qore_soft_bool_data_type.html", "class_data_provider_1_1_qore_soft_bool_data_type" ],
    [ "QoreSoftBoolNoNullDataType", "class_data_provider_1_1_qore_soft_bool_no_null_data_type.html", null ],
    [ "QoreSoftBoolOrNothingDataType", "class_data_provider_1_1_qore_soft_bool_or_nothing_data_type.html", "class_data_provider_1_1_qore_soft_bool_or_nothing_data_type" ],
    [ "QoreSoftDateDataType", "class_data_provider_1_1_qore_soft_date_data_type.html", "class_data_provider_1_1_qore_soft_date_data_type" ],
    [ "QoreSoftDateNoNullDataType", "class_data_provider_1_1_qore_soft_date_no_null_data_type.html", "class_data_provider_1_1_qore_soft_date_no_null_data_type" ],
    [ "QoreSoftDateOrNothingDataType", "class_data_provider_1_1_qore_soft_date_or_nothing_data_type.html", "class_data_provider_1_1_qore_soft_date_or_nothing_data_type" ],
    [ "QoreSoftFloatDataType", "class_data_provider_1_1_qore_soft_float_data_type.html", "class_data_provider_1_1_qore_soft_float_data_type" ],
    [ "QoreSoftFloatNoNullDataType", "class_data_provider_1_1_qore_soft_float_no_null_data_type.html", "class_data_provider_1_1_qore_soft_float_no_null_data_type" ],
    [ "QoreSoftFloatOrNothingDataType", "class_data_provider_1_1_qore_soft_float_or_nothing_data_type.html", "class_data_provider_1_1_qore_soft_float_or_nothing_data_type" ],
    [ "QoreSoftIntDataType", "class_data_provider_1_1_qore_soft_int_data_type.html", "class_data_provider_1_1_qore_soft_int_data_type" ],
    [ "QoreSoftIntNoNullDataType", "class_data_provider_1_1_qore_soft_int_no_null_data_type.html", "class_data_provider_1_1_qore_soft_int_no_null_data_type" ],
    [ "QoreSoftIntOrNothingDataType", "class_data_provider_1_1_qore_soft_int_or_nothing_data_type.html", "class_data_provider_1_1_qore_soft_int_or_nothing_data_type" ],
    [ "QoreSoftNumberDataType", "class_data_provider_1_1_qore_soft_number_data_type.html", "class_data_provider_1_1_qore_soft_number_data_type" ],
    [ "QoreSoftNumberNoNullDataType", "class_data_provider_1_1_qore_soft_number_no_null_data_type.html", "class_data_provider_1_1_qore_soft_number_no_null_data_type" ],
    [ "QoreSoftNumberOrNothingDataType", "class_data_provider_1_1_qore_soft_number_or_nothing_data_type.html", "class_data_provider_1_1_qore_soft_number_or_nothing_data_type" ],
    [ "QoreSoftStringDataType", "class_data_provider_1_1_qore_soft_string_data_type.html", "class_data_provider_1_1_qore_soft_string_data_type" ],
    [ "QoreSoftStringOrNothingDataType", "class_data_provider_1_1_qore_soft_string_or_nothing_data_type.html", "class_data_provider_1_1_qore_soft_string_or_nothing_data_type" ],
    [ "QoreStringDataType", "class_data_provider_1_1_qore_string_data_type.html", "class_data_provider_1_1_qore_string_data_type" ],
    [ "QoreStringDataTypeBase", "class_data_provider_1_1_qore_string_data_type_base.html", "class_data_provider_1_1_qore_string_data_type_base" ],
    [ "QoreStringOrNothingDataType", "class_data_provider_1_1_qore_string_or_nothing_data_type.html", "class_data_provider_1_1_qore_string_or_nothing_data_type" ],
    [ "SearchOperatorInfo", "struct_data_provider_1_1_search_operator_info.html", "struct_data_provider_1_1_search_operator_info" ],
    [ "SoftListDataType", "class_data_provider_1_1_soft_list_data_type.html", "class_data_provider_1_1_soft_list_data_type" ],
    [ "dp_make_op", "namespace_data_provider.html#ae3e2cb7feb5f9ef23a369af5895fc7f8", null ],
    [ "dp_op_between", "namespace_data_provider.html#a48fc91fc206c8dc5b302ae2d1ff29136", null ],
    [ "dp_op_eq", "namespace_data_provider.html#a05d0acdf0ef37c3f52d054ae2da89727", null ],
    [ "dp_op_ge", "namespace_data_provider.html#a8a3b2384b97a6b7c3805e53a70a13733", null ],
    [ "dp_op_gt", "namespace_data_provider.html#afd5e01ef5eaeb53dae6b3c275356ef2f", null ],
    [ "dp_op_in", "namespace_data_provider.html#ac4707163207999fed2944b3f5e83fc98", null ],
    [ "dp_op_in", "namespace_data_provider.html#a1bd890920bd084fd948cd4020e48a81c", null ],
    [ "dp_op_le", "namespace_data_provider.html#aa53ff2f588d1ba280f624588a380772c", null ],
    [ "dp_op_like", "namespace_data_provider.html#ab154e266fc168f8672665ec97762886b", null ],
    [ "dp_op_lt", "namespace_data_provider.html#aecfc72fe0506ef4ef8f71d54dda428ed", null ],
    [ "dp_op_ne", "namespace_data_provider.html#a8acc6fd3eddc51adc42e95cb38b9faa8", null ],
    [ "dp_op_not", "namespace_data_provider.html#a84d55503a3274c1377f7e6b94743ca0b", null ],
    [ "dp_op_regex", "namespace_data_provider.html#a8356adb323d7ab6c787b7344db4661f5", null ],
    [ "AbstractDataProviderTypeMap", "namespace_data_provider.html#a9a5a795ede30c8e9c3c4b7da14c376c3", null ],
    [ "DataProviderSignatureAnyType", "namespace_data_provider.html#aa0f33d609a461fdaaca22e4be824c4b8", null ],
    [ "DataProviderSignatureBoolType", "namespace_data_provider.html#a888f587fb265e74db6eb3facb40a2950", null ],
    [ "DataProviderSignatureDateType", "namespace_data_provider.html#a352e6fcdfe99598e2f8ce1d7f42b974e", null ],
    [ "DataProviderSignatureFieldType", "namespace_data_provider.html#a8145185ec847aa58de3d4d59a429af4c", null ],
    [ "DataProviderSignatureHashValueType", "namespace_data_provider.html#a3dc085788ac69d27009e8e672d203a54", null ],
    [ "DataProviderSignatureIntValueType", "namespace_data_provider.html#afa4ac1d3ed96eda27807373121922ae0", null ],
    [ "DataProviderSignatureListValueType", "namespace_data_provider.html#a9af8e56ec6792893a014aa7e88e49668", null ],
    [ "DataProviderSignatureOptionalIntValueType", "namespace_data_provider.html#a1f922a9df6217247912ba3b0542b0ee2", null ],
    [ "DataProviderSignatureOptionalStringValueType", "namespace_data_provider.html#a626e04cae22b724cebd17dd2f1fae99e", null ],
    [ "DataProviderSignatureStringType", "namespace_data_provider.html#a27b67b166003b6242e1ffd3766f75123", null ],
    [ "DataProviderSignatureStringValueType", "namespace_data_provider.html#a9d3d58a5fdf30e55e9e544a61b7639a4", null ],
    [ "DataTypeMap", "namespace_data_provider.html#a1cf50c6d0d820d1fef1fa6d96dc10286", null ],
    [ "DefaultGenericSearchOpMap", "namespace_data_provider.html#a7d5588275ac693e3249eca1d41902681", null ],
    [ "DET_Function", "namespace_data_provider.html#a760e1a853d172bb46dfb63cd36c564be", null ],
    [ "DET_Operator", "namespace_data_provider.html#a54c149affb42d6c13f37924fcb8736e7", null ],
    [ "DP_OP_AND", "namespace_data_provider.html#a7fd749f37cd38b4c240f512aed2396d0", null ],
    [ "DP_OP_OR", "namespace_data_provider.html#a0f8b80e1b5ecb3fa17caecf5662ed53f", null ],
    [ "DP_SEARCH_OP_BETWEEN", "namespace_data_provider.html#a7a06f4bf75875254951a6fdd589d277e", null ],
    [ "DP_SEARCH_OP_EQ", "namespace_data_provider.html#a0281465b064499e2d96009eed9aebf2c", null ],
    [ "DP_SEARCH_OP_GE", "namespace_data_provider.html#a6b334267cd573d2e3c86b86a3587ef39", null ],
    [ "DP_SEARCH_OP_GT", "namespace_data_provider.html#a1ef8cb0608c74b6f61d39fb51a25ddbe", null ],
    [ "DP_SEARCH_OP_IN", "namespace_data_provider.html#a40c6d3d1903c0bdaf6a8879a3634cce3", null ],
    [ "DP_SEARCH_OP_LE", "namespace_data_provider.html#ad98e21a3cee80a6ae168e8f7ed56aad0", null ],
    [ "DP_SEARCH_OP_LT", "namespace_data_provider.html#aaec7428d9557a1b32952a3ec9be54bce", null ],
    [ "DP_SEARCH_OP_NE", "namespace_data_provider.html#a81cabee5ad3c7b6a6da0b32e36e47f00", null ],
    [ "DP_SEARCH_OP_NOT", "namespace_data_provider.html#a84e33e770bc4dcf5d0e9b68acad3fe69", null ],
    [ "DP_SEARCH_OP_REGEX", "namespace_data_provider.html#a10163f0db28f6fb1b07f4730205b6c53", null ],
    [ "DPSP_REST", "namespace_data_provider.html#a538f5dbfde75ace74f8b356b3c9b0c61", null ],
    [ "DPSP_SOAP", "namespace_data_provider.html#a11a0703d54fe8cae8f30276a8f4eff64", null ],
    [ "DTT_ClientOnly", "namespace_data_provider.html#afaad4553843de6f086c8a35a852268d5", null ],
    [ "DTT_FromFile", "namespace_data_provider.html#a8c33b44c1d10d6717443cc74328b6b20", null ],
    [ "DTT_FromLocation", "namespace_data_provider.html#a4c766723e4735321c7726ca574e13314", null ],
    [ "ER_All", "namespace_data_provider.html#a064c0d1f27aa04752971b68af69543c7", null ],
    [ "ER_Field", "namespace_data_provider.html#ae064efa9126c48c9b3276592b29e4b97", null ],
    [ "ER_Search", "namespace_data_provider.html#a3f52cf1fcd1d3584090fd8d8f3694573", null ],
    [ "ExpressionTypeCodeMap", "namespace_data_provider.html#aea7722e98943e0affb132e2e4b082797", null ],
    [ "ExpressionTypeDescMap", "namespace_data_provider.html#a882d4436b705cb163e50475d8425bb92", null ],
    [ "LC_All", "namespace_data_provider.html#ac1c41de7036241094caf33e12f9740c2", null ],
    [ "LC_And", "namespace_data_provider.html#a71e131dc7d536df7ca56580fbb6dc887", null ],
    [ "LC_Or", "namespace_data_provider.html#a3d11437e11bd685735af1a4fe389a3e8", null ],
    [ "LogicCodeMap", "namespace_data_provider.html#ad8952d326b2c957f9890e41949e61040", null ],
    [ "LogicDescMap", "namespace_data_provider.html#a6b27c79c785169af56d53dc00009beb8", null ],
    [ "OptimalQoreDataTypeMap", "namespace_data_provider.html#a567cffd7c0cc75d1a8eccba70b9734aa", null ],
    [ "OptimalQoreSoftDataTypeMap", "namespace_data_provider.html#af449e42387d995a2c036b3645466daa2", null ],
    [ "PipelineQueueInfo", "namespace_data_provider.html#a7b116d3c8f13ed7db50709fcd54e8015", null ],
    [ "PS_ABORTED", "namespace_data_provider.html#aec6ef2bfccb4b29280fb887f77d0e489", null ],
    [ "PS_IDLE", "namespace_data_provider.html#a0e52b5bef78318dda11051f5954345ef", null ],
    [ "PS_RUNNING", "namespace_data_provider.html#a7576870ea3b62fcea7cba0e64195ffdf", null ],
    [ "RoleCodeMap", "namespace_data_provider.html#ab60d9483a4186513c62fc96b0a08741e", null ],
    [ "RoleDescMap", "namespace_data_provider.html#ad9a0d0302a10f1e56f73069a826ac218", null ],
    [ "SignatureTypeCodeMap", "namespace_data_provider.html#a4f94d2d029713d9e3cefe126a2452c7c", null ],
    [ "SignatureTypeDescMap", "namespace_data_provider.html#a4ecf82161a3fd015ddc1a1ec781eeedd", null ],
    [ "ST_Any", "namespace_data_provider.html#ac6b11fea94f8c37a2aecb292591e8351", null ],
    [ "ST_Field", "namespace_data_provider.html#aa19c0ad5db7458b33df45f2e3f428b78", null ],
    [ "ST_Value", "namespace_data_provider.html#a17f61e6fae0c6df2df438b874537bdae", null ],
    [ "TypeCodeMap", "namespace_data_provider.html#a85f497b926e1454d778f3b3aeb4f4071", null ],
    [ "UpsertResultDeleted", "namespace_data_provider.html#a01f22e475a1dc7597630dadad05c4db5", null ],
    [ "UpsertResultInserted", "namespace_data_provider.html#a0e0c7514f35d70435a79a7c78fdc358d", null ],
    [ "UpsertResultUnchanged", "namespace_data_provider.html#a009a310c4332f201802c95f6a6c14d10", null ],
    [ "UpsertResultUpdated", "namespace_data_provider.html#ab75129e464056c5bde73952d08bc0e6b", null ],
    [ "UpsertResultVerified", "namespace_data_provider.html#aa4b32a83bd3fe0195843e44846dbdabe", null ]
];